//  
//   Rebex Sample Code License
// 
//   Copyright 2024, REBEX CR s.r.o.
//   All rights reserved.
//   https://www.rebex.net/
// 
//   Permission to use, copy, modify, and/or distribute this software for any
//   purpose with or without fee is hereby granted.
// 
//   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
//   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
//   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
//   HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
//   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
//   OTHER DEALINGS IN THE SOFTWARE.
// 

using System;
using Rebex.Net;

namespace Rebex.Samples
{
    /// <summary>
    /// This sample asks a time server for time and calculates its difference
    /// from time on the local machine.
    /// </summary>
    class GetTimeDifference
    {
        [STAThread]
        static void Main(string[] args)
        {
            // set the trial license key
            Rebex.Licensing.Key = Rebex.Samples.TrialKey.Key;


            if (args.Length != 1)
            {
                Console.WriteLine("Usage: TimeGetTimeDifference server.name");
                Console.WriteLine("Example: TimeGetTimeDifference test.rebex.net");
                return;
            }

            Ntp client = new Ntp(args[0]);
            TimeSpan offset = client.GetTime().TimeOffset.ToTimeSpan();
            if (offset.Ticks >= 0)
            {
                Console.WriteLine("Server's time is {0} seconds before local time.", offset.TotalSeconds);
            }
            else
            {
                TimeSpan ats = new TimeSpan(-offset.Ticks);
                Console.WriteLine("Server's time is {0} seconds behind local time.", ats.TotalSeconds);
            }
        }
    }
}
